@@ -4,5 +4,5 @@
 #include "spvm_compiler.h"
 
 SPVM_FIELD_ACCESS* SPVM_FIELD_ACCESS_new(SPVM_COMPILER* compiler) {
-  return SPVM_ALLOCATOR_new_block_compile_tmp(compiler->allocator, sizeof(SPVM_FIELD_ACCESS));
+  return SPVM_ALLOCATOR_alloc_memory_block_tmp(compiler->allocator, sizeof(SPVM_FIELD_ACCESS));
 }
