@@ -10,9 +10,8 @@ use File::Find 'find';
 use File::Basename 'dirname', 'basename';
 use SPVM::Builder::Util;
 use Getopt::Long 'GetOptions';
-use Time::Piece();
 
-# Field metods
+# Fields
 sub force {
   my $self = shift;
   if (@_) {
@@ -68,17 +67,6 @@ sub precompile {
   }
 }
 
-sub resource {
-  my $self = shift;
-  if (@_) {
-    $self->{resource} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{resource};
-  }
-}
-
 sub only_lib_files {
   my $self = shift;
   if (@_) {
@@ -112,68 +100,6 @@ sub lib_dir {
   }
 }
 
-sub user_name {
-  my $self = shift;
-  if (@_) {
-    $self->{user_name} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{user_name};
-  }
-}
-
-sub user_email {
-  my $self = shift;
-  if (@_) {
-    $self->{user_email} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{user_email};
-  }
-}
-
-# Class methods
-sub new {
-  my $class = shift;
-  
-  my $self = {@_};
-  
-  bless $self, $class;
-
-  # Class name
-  my $class_name = $self->class_name;
-  unless (defined $self->class_name) {
-    confess "Class name must be specified";
-  }
-  
-  if (defined $self->output_dir) {
-    # Remove tailing / or \
-    my $output_dir = $self->output_dir;
-    $output_dir =~ s|[/\\]$||;
-    $self->output_dir($output_dir);
-  }
-  else {
-    my $default_output_dir = "SPVM::$class_name";
-    $default_output_dir =~ s/::/-/g;
-    $self->output_dir($default_output_dir);
-  }
-  
-  my $native = $self->native;
-  if (defined $native && !($native eq 'c' || $native eq 'c++')) {
-    confess "Can't support native \"$native\"";
-  }
-  
-  my $resource = $self->resource;
-  if ($resource && !defined $native) {
-    $self->native('c');
-  }
-  
-  return $self;
-}
-
-# Instance methods
 sub create_path {
   my ($self, $file_base_name) = @_;
   
@@ -233,6 +159,39 @@ sub generate_dir {
   }
 }
 
+sub new {
+  my $class = shift;
+  
+  my $self = {@_};
+  
+  bless $self, $class;
+
+  # Class name
+  my $class_name = $self->class_name;
+  unless (defined $self->class_name) {
+    confess "Class name must be specified";
+  }
+  
+  if (defined $self->output_dir) {
+    # Remove tailing / or \
+    my $output_dir = $self->output_dir;
+    $output_dir =~ s|[/\\]$||;
+    $self->output_dir($output_dir);
+  }
+  else {
+    my $default_output_dir = "SPVM::$class_name";
+    $default_output_dir =~ s/::/-/g;
+    $self->output_dir($default_output_dir);
+  }
+  
+  my $native = $self->native;
+  if (defined $native && !($native eq 'c' || $native eq 'c++')) {
+    confess "Can't support native \"$native\"";
+  }
+
+  return $self;
+}
+
 sub generate_spvm_module_file {
   my ($self) = @_;
   
@@ -258,22 +217,6 @@ sub generate_perl_module_file {
   # Class name
   my $class_name = $self->class_name;
   
-  # Year
-  my $today_tp = Time::Piece::localtime;
-  my $year = $today_tp->year;
-  
-  # User name
-  my $user_name = $self->user_name;
-  unless (defined $user_name) {
-    $user_name = '[--user-name]'
-  }
-  
-  # User email
-  my $user_email = $self->user_email;
-  unless (defined $user_email) {
-    $user_email = '[--user-email]'
-  }
-  
   # Content
   my $perl_module_content = <<"EOS";
 package SPVM::$class_name;
@@ -282,41 +225,45 @@ our \$VERSION = '0.01';
 
 1;
 
-=head1 Name
+=head1 NAME
 
 SPVM::$class_name - $class_name is a SPVM module
 
-=head1 Usage
+=head1 SYNOPSYS
 
   use $class_name;
   
-=head1 Description
+=head1 DESCRIPTION
 
-C<$class_name> is a L<SPVM> module.
+$class_name is a SPVM module.
 
-=head1 Field Methods
+=head1 STATIC METHODS
 
 
 
-=head1 Class Methods
+=head1 INSTANCE METHODS
 
 
 
-=head1 Instance Methods
+=head1 REPOSITORY
 
 
 
-=head1 Repository
+=head1 BUG REPORT
 
 
 
-=head1 Author
+=head1 SUPPORT
 
-$user_name C<$user_email>
 
-=head1 Copyright & License
 
-Copyright $year-$year $user_name, all rights reserved.
+=head1 AUTHOR
+
+
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright YYYY-YYYY AUTHOR_NAME, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -351,9 +298,9 @@ use strict;
 use warnings;
 use SPVM::Builder::Config;
 
-my \$config = SPVM::Builder::Config->$new_method(file => __FILE__);
+my \$native_config = SPVM::Builder::Config->$new_method;
 
-\$config;
+\$native_config;
 EOS
 
   # Generate file
@@ -443,7 +390,7 @@ sub generate_gitkeep_file_for_native_module_src_dir {
 sub generate_gitignore_file {
   my ($self) = @_;
   
-  my $gitignore_content = <<'EOS';
+  my $gitignore_content = <<"EOS";
 blib/*
 Makefile
 Makefile.old
@@ -458,8 +405,6 @@ SPVM-*
 *.bak
 *.BAK
 *.tmp
-*.o
-*.bs
 EOS
   
   # Generate file
@@ -471,24 +416,22 @@ sub generate_manifest_skip_file {
   my ($self) = @_;
   
   # Content
-  my $manifest_skip_content = <<'EOS';
-(^|\/)blib/
-(^|\/)Makefile$
-(^|\/)Makefile.old$
-(^|\/)MYMETA.yml$
-(^|\/)MYMETA.json$
-(^|\/)pm_to_blib$
-(^|\/).spvm_build/
-(^|\/)t/.spvm_build/
-(^|\/)SPVM-
-(^|\/)core\.
-(^|\/)core$
-(^|\/)\.git/
-\.bak$
-\.tmp$
-\.BAK$
-\.o$
-\.bs$
+  my $manifest_skip_content = <<"EOS";
+^blib/
+^Makefile\$
+^Makefile\.old\$
+^MYMETA.yml\$
+^MYMETA.json\$
+^pm_to_blib\$
+^\.spvm_build\$
+^t/\.spvm_build\$
+^SPVM-
+^core\.
+^core\$
+\.bak\$
+\.tmp\$
+\.BAK\$
+^\.git/
 EOS
 
   # Generate file
@@ -498,16 +441,12 @@ EOS
 
 sub generate_changes_file {
   my ($self) = @_;
-
-  # Year
-  my $today_tp = Time::Piece::localtime;
-  my $today = $today_tp->strftime('%Y-%m-%d');
   
   # Content
   my $changes_content = <<"EOS";
-0.01 $today
-  [Changes]
-    * First release.
+0.01  YYYY-MM-DD
+
+  -
   
 EOS
 
@@ -541,15 +480,12 @@ sub generate_makefile_pl_file {
   
   # Class name
   my $class_name = $self->class_name;
-  
-  # Resource
-  my $resource = $self->resource;
-  
+
   # Native make rule
-  my $make_rule_native = $self->native && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_native('$class_name');" : '';
+  my $make_rule_native = $self->native ? "SPVM::Builder::Util::API::create_make_rule_native('$class_name');" : '';
   
   # Precompile make rule
-  my $make_rule_precompile = $self->precompile && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_precompile('$class_name');" : '';
+  my $make_rule_precompile = $self->precompile ? "SPVM::Builder::Util::API::create_make_rule_precompile('$class_name');" : '';
 
   my $perl_module_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'pm');
   $perl_module_rel_file =  $self->create_lib_rel_file($perl_module_rel_file);
@@ -566,11 +502,12 @@ use SPVM::Builder::Util::API;
 WriteMakefile(
   NAME              => 'SPVM::$class_name',
   VERSION_FROM      => '$perl_module_rel_file',
+  PREREQ_PM         => {}, # e.g., Module::Name => 1.1
   LICENSE           => 'perl_5',
   (\$] >= 5.005 ?     ## Add these new keywords supported since 5.005
     (ABSTRACT_FROM  => '$perl_module_rel_file',
      AUTHOR         => 'USER_NAME<USER_MAIL>') : ()),
-  test => {TESTS => 't/*.t t/*/*.t t/*/*/*.t'},
+  test => {TESTS => 't/*.t'},
   clean => {FILES => ['.spvm_build', 't/.spvm_build']},
   META_MERGE => {
     'meta-spec' => { version => 2 },
@@ -581,21 +518,11 @@ WriteMakefile(
         web  => '',
       },
     },
-    no_index => {
-      directory => [],
-    }
   },
-  NORECURS => 1,
+  # SPVM::Builder::Util::API is needed for Makefile.PL
   CONFIGURE_REQUIRES => {
-    # SPVM::Builder::Util::API is needed for Makefile.PL
     'SPVM'              => '$SPVM::VERSION',
   },
-  PREREQ_PM => {
-    
-  },
-  TEST_REQUIRES => {
-    
-  },
 );
 
 sub MY::postamble {
@@ -624,172 +551,28 @@ sub generate_basic_test_file {
   
   # Content
   my $basic_test_content = <<"EOS";
-use Test::More;
-
 use strict;
 use warnings;
-use FindBin;
-use lib "\$FindBin::Bin/lib";
-BEGIN { \$ENV{SPVM_BUILD_DIR} = "\$FindBin::Bin/.spvm_build"; }
+use Test::More;
 
-use SPVM 'TestCase::$class_name';
+use SPVM '$class_name';
 
-ok(SPVM::TestCase::$class_name->test);
+ok(1);
 
 done_testing;
 EOS
   
   # Generate file
-  my $basic_test_rel_file = 't/use_spvm_class.t';
+  my $basic_test_rel_file = 't/basic.t';
   $self->generate_file($basic_test_rel_file, $basic_test_content);
 }
 
-sub generate_basic_test_spvm_module_file {
-  my ($self) = @_;
-  
-  # Class name
-  my $class_name = $self->class_name;
-  
-  # Resource
-  my $resource = $self->resource;
-  
-  # Content
-  my $basic_test_spvm_module_content;
-  
-  if ($resource) {
-    $basic_test_spvm_module_content = <<"EOS";
-class TestCase::$class_name {
-  native static method test : int ();
-}
-EOS
-  }
-  else {
-    $basic_test_spvm_module_content = <<"EOS";
-class TestCase::$class_name {
-  use $class_name;
-  static method test : int () {
-    
-    return 1;
-  }
-}
-EOS
-  }
-  
-  # Generate file
-  my $basic_test_spvm_module_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", 'spvm');
-  $basic_test_spvm_module_rel_file = "t/lib/$basic_test_spvm_module_rel_file";
-  $self->generate_file($basic_test_spvm_module_rel_file, $basic_test_spvm_module_content);
-}
-
-sub generate_basic_test_native_config_file {
-  my ($self) = @_;
-  
-  # Class name
-  my $class_name = $self->class_name;
-  
-  # Resource
-  my $resource = $self->resource;
-
-  # C or C++
-  my $native = $self->native;
-  my $new_method;
-  if ($native eq 'c') {
-    $new_method = 'new_gnu99';
-  }
-  elsif ($native eq 'c++') {
-    $new_method = 'new_cpp';
-  }
-  
-  # Content
-  my $basic_test_native_config_content = <<"EOS";
-use strict;
-use warnings;
-
-my \$config = SPVM::Builder::Config->$new_method(file => __FILE__);
-
-\$config->use_resource('$class_name');
-
-\$config;
-EOS
-  
-  # Generate file
-  my $basic_test_native_config_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", 'config');
-  $basic_test_native_config_rel_file = "t/lib/$basic_test_native_config_rel_file";
-  $self->generate_file($basic_test_native_config_rel_file, $basic_test_native_config_content);
-}
-
-sub generate_basic_test_native_module_file {
-  my ($self) = @_;
-  
-  # Class name
-  my $class_name = $self->class_name;
-  
-  # Resource
-  my $resource = $self->resource;
-
-  # extern C for C++
-  my $native = $self->native;
-  my $extern_c_start;
-  my $extern_c_end;
-  if ($native eq 'c++') {
-    $extern_c_start = qq(extern "C" {);
-    $extern_c_end = "}";
-  }
-  else {
-    $extern_c_start = '';
-    $extern_c_end = '';
-  }
-  
-  # Content
-  my $native_class_name = $class_name;
-  $native_class_name =~ s/::/__/g;
-  my $basic_test_native_module_content = <<"EOS";
-#include "spvm_native.h"
-
-$extern_c_start
-
-int32_t SPVM__TestCase__${native_class_name}__test(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  (void)stack;
-  
-  stack[0].ival = 1;
-  
-  return 0;
-}
-
-$extern_c_end
-EOS
-  
-  # Generate file
-  my $native_module_ext;
-  if (defined $native) {
-    if ($native eq 'c') {
-      $native_module_ext = 'c';
-    }
-    elsif ($native eq 'c++') {
-      $native_module_ext = 'cpp';
-    }
-  }
-  my $basic_test_native_module_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", $native_module_ext);
-  $basic_test_native_module_rel_file = "t/lib/$basic_test_native_module_rel_file";
-  $self->generate_file($basic_test_native_module_rel_file, $basic_test_native_module_content);
-}
-
 sub generate_dist {
   my ($self) = @_;
   
   my $class_name = $self->class_name;
   
-  unless (length $class_name) {
-    confess "The class name must be specified";
-  }
-  
-  if ($class_name =~ /-/) {
-    confess "The class name can't contain \"-\"";
-  }
-  
   my $native = $self->native;
-  my $resource = $self->resource;
   
   my $class_name_rel_file = $class_name;
   $class_name_rel_file =~ s|::|/|g;
@@ -799,10 +582,8 @@ sub generate_dist {
   $self->generate_dir($output_dir);
   
   # Generate SPVM module file
-  unless ($resource) {
-    $self->generate_spvm_module_file;
-  }
-  
+  $self->generate_spvm_module_file;
+
   # Generate Perl module file
   my $no_pm_file = $self->no_pm_file;
   unless ($no_pm_file) {
@@ -814,9 +595,7 @@ sub generate_dist {
     $self->generate_native_config_file;
     
     # Generate native module file
-    unless ($resource) {
-      $self->generate_native_module_file;
-    }
+    $self->generate_native_module_file;
     
     # Generate ".gitkeep" file for native module include directory
     $self->generate_gitkeep_file_for_native_module_include_dir;
@@ -842,25 +621,14 @@ sub generate_dist {
     # Generate Makefile.PL file
     $self->generate_makefile_pl_file;
     
-    # Generate t/use_spvm_class.t file
+    # Generate t/basic.t file
     $self->generate_basic_test_file;
-
-    # Generate basic test SPVM module file
-    $self->generate_basic_test_spvm_module_file;
-
-    if ($resource) {
-      # Generate basic test native module file
-      $self->generate_basic_test_native_module_file;
-
-      # Generate basic test native config file
-      $self->generate_basic_test_native_config_file;
-    }
   }
 }
 
 1;
 
-=head1 Name
+=head1 NAME
 
 SPVM::Dist - Generating SPVM Distrubution
 
